############################################################################
############################################################################
############################################################################
############################################################################
fitPB <- function(x, y, weights, data,  xmin, xmax, nseg = 10,
                  lambda = 10, order=2, degree=3, 
                  plot=TRUE, ylim)
{
############################################################################
bbase <- function(x, xl, xr, ndx, deg)
  {
# Truncated p-th power function  
    tpower <- function(x, t, p) (x - t) ^ p * (x > t)
       dx <- (xr - xl) / ndx # DS increment 
    knots <- seq(xl - deg * dx, xr + deg * dx, by = dx)
        P <- outer(x, knots, tpower, deg)# calculate the power in the knots
        n <- dim(P)[2]
        D <- diff(diag(n), diff = deg + 1) / (gamma(deg + 1) * dx ^ deg) # 
        B <- (-1) ^ (deg + 1) * P %*% t(D)
      attr(B, "knots") <- knots
      attr(B, "rest") <- c(xmin=xl, xmax=xr, nknots=ndx, degree=deg)
    B 
  }
###################################################################  
   lower <- upper <- knots <- NULL
   scall <- deparse(sys.call())
   xname <- deparse(substitute(x))
   yname <- deparse(substitute(y))
       y <- if (!missing(data)) 
           get(deparse(substitute(y)), envir = as.environment(data))
           else y
      x <- if (!missing(data)) 
           get(deparse(substitute(x)), envir = as.environment(data))
           else x
      w <- if (!missing(data)) 
           if (missing(weights)) w <- rep(1, length(x))
           else w <- get(deparse(substitute(weights)), envir = as.environment(data))
           else 
           {
           if (missing(weights)) w <- rep(1, length(x))
           else weights
           }
if (length(w)!=length(y)) stop("response and weights should be the same length")
   xmin <- if (missing(xmin))  min(x) else xmin
   xmax <- if (missing(xmax))  max(x) else xmax
#     x1 <- seq(min(x), max(x), length=500)
      B <- bbase(x,  xl = min(x), xr = max(x), ndx=nseg, deg=degree)
     nb <- ncol(B)# may taake off 
      D <- diff(diag(nb), diff = order)
      p <- ncol(D)
      N <- sum(w!=0) # DS+FDB 3-2-14
      n <- nrow(B) # the no of observations
    qrX <- qr(sqrt(w)*B, tol=.Machine$double.eps^.8)  
      R <- qr.R(qrX)
      Q <- qr.Q(qrX) 
     Qy <- t(Q)%*%(sqrt(w)*y)
   tau2 <- sig2 <- NULL
if (lambda>=1e+07) lambda <- 1e+07 # MS 19-4-12
if (lambda<=1e-07) lambda <- 1e-07 # MS 19-4-12
#############################################################################
  regpen <- function(y, X, w, lambda, D)# original
  {
    RD <- rbind(R,sqrt(lambda)*D) # 2p x p matrix 
 svdRD <- svd(RD)                 # U 2pxp D pxp V pxp
    ##                                        take only the important values    
  rank <- sum(svdRD$d>max(svdRD$d)*.Machine$double.eps^.8)
    U1 <- svdRD$u[1:p,1:rank]     # U1 p x rank 
    y1 <- t(U1)%*%Qy              # rankxp pxn nx1 => rank x 1 vector 
  beta <- svdRD$v[,1:rank] %*%(y1/svdRD$d[1:rank])
    HH <- (svdRD$u)[1:p,1:rank]%*%t(svdRD$u[1:p,1:rank])
    df <- sum(diag(HH))
  Vcov <-  svdRD$v%*%diag(1/svdRD$d^2)%*%t(svdRD$v)# added 21-3-2021
   fit <- list(beta = beta, edf = df, lev=diag(HH), vcov=Vcov)
return(fit)  
  }
############################################################################
   fit <- regpen(y, B, w, lambda,  D)
    fv <- B %*% fit$beta   
for (it in 1:50) 
  {
   fit <- regpen(y, B, w, lambda, D) # fit model
gamma. <- D %*% as.vector(fit$beta)  # get the gamma differences
    fv <- B %*% fit$beta             # fitted values
  sig2 <- sum(w * (y - fv) ^ 2) / (N - fit$edf) # DS+FDB 3-2-14
  tau2 <- sum(gamma. ^ 2) / (fit$edf-order)# see LNP page 279
if(tau2<1e-7) tau2 <- 1.0e-7 # MS 19-4-12
lambda.old <- lambda
lambda <- sig2 / tau2 # maybe only 1/tau2 will do since it gives exactly the EM results see LM-1
if (lambda<1.0e-7) lambda<-1.0e-7 # DS Saturday, April 11, 2009 at 14:18
if (lambda>1.0e+7) lambda<-1.0e+7 # DS 29 3 2012
if (abs(lambda-lambda.old) < 1.0e-7||lambda>1.0e10) break
  }
#############################################################################
  waug <- as.vector(c(w, rep(1,nrow(D))))
  xaug <- as.matrix(rbind(B,sqrt(lambda)*D))
   lev <- hat(sqrt(waug)*xaug,intercept=FALSE)[1:n] # get the hat matrix
   var <- (lev/w)*sig2 
# different way is to calculate the vcoc of gamma   
   vg  <-  fit$vcov*sig2
# this can be done also using PB equation 2.16   
# vgamma <- solve(t(B)%*%diag(w)%*%B+lambda*t(D)%*%D)*sig2
 varfv <- B%*%vg%*%t(B) # variance covariance for fitted values n*n
# var and diag(varfv) should be identical
# plot(diag(varfv),var); lines(var, var)
if (plot)
  {
    
    df <- data.frame(y=y, x=x, fv=fv, lower=fv-2*sqrt(var), upper=fv+2*sqrt(var)) 
    #   theme_bw(base_size = 18)
    gg <- ggplot(data=df, aes(x=x, y=y))+
          geom_point(, col="black", size=0.5)+
          geom_line( aes(x=x, y=fv), col="blue", size=1)+
          ylab(yname)+ xlab(xname)+
          geom_ribbon(data=df, aes(ymin = lower, ymax = upper, x = x), alpha=.5, col="gray")
    print(gg)
  }
     x1 <- seq(min(x), max(x), length=500)
   rest <- attr(B, "rest")
     B1 <- bbase(x=x1,  xl = rest[1], xr = rest[2],  ndx = rest[3], deg = degree)
  knots <- attr(B1,"knots")
      z <- B1 %*% fit$beta   
  suppressWarnings(
         Fun <- splinefun(x1, z, method="natural"))
          s1 <- sqrt(sig2)
    deviance <- sum(-2*dNO(y, mu=fv, sigma=s1, log=TRUE))
devianceIncr <- -2*dNO(y, mu=fv, sigma=s1, log=TRUE)
           G <- t(D)%*%D
         pen <- lambda* t(fit$beta)%*%G%*%fit$beta 
           M <- list(call = scall, y = y, x = x, fv = fv, coef = fit$beta, 
                   lambda = lambda, sig = s1, sigb = sqrt(tau2), fun = Fun,  
                        B = B,  deviance = deviance, df = fit$edf, vcov.coef = vg,
                    varfv = var, 
                    xname = xname, yname = yname, penalty = pen,  knots = knots,
             devianceIncr = devianceIncr)
  class(M) <- "Psplines"
  invisible(M)
}
################################################################
################################################################
################################################################
################################################################
################################################################
################################################################
################################################################
print.Psplines <- function (x, digits = max(3, getOption("digits") - 3), ...) 
{   
  cat("P-spline fit of", x$yname, "against", x$xname, "using fitPB() \n")
  cat("Degrees of Freedom for the fit :", x$df, "\n")
  # cat("Random effect parameter sigma_b:", format(signif(x$sigb)), "\n")  
  cat("Smoothing parameter lambda     :", format(signif(x$lambda)), "\n") 
}
###############################################################
fitted.Psplines <- function(object)
{
  as.vector(object$fv)  
}
###############################################################
###############################################################
###############################################################
deviance.Psplines <- function(object)
{
  as.vector(object$deviance)  
}
###############################################################
###############################################################
###############################################################
predict.Psplines <- function(object, newdata=NULL)
{
  pred <-  if (is.null(newdata)) object$fv
           else    object$fun(newdata)
  pred
}
###############################################################
###############################################################
###############################################################
coef.Psplines <- function(object)
{
  as.vector(object$coef)
}
###############################################################
###############################################################
###############################################################
residuals.Psplines  <- function(obj)
{
  as.vector(obj$y - obj$fv)
}

# plot_fun <- function(obj, xlim=c(0, 1), ylim=c(-3,30))
# {
#   curve(obj$fun(x, deriv=0),  xlim[1],xlim[2], ylim=ylim)
#   curve(obj$fun(x, deriv=1), add=T, col="red", 0,20)
#   abline(h=0)
# }
###############################################################
###############################################################
###############################################################
# plot.Psplines <- function(obj, deriv=0)
# {
#  # browser()
#  # df <- data.frame(y=obj$y, x=obj$x, fv=obj$fv)
#   xmin <- min(obj$x)
#   xmax <- max(obj$x)
#   ymin <- min(obj$y)
#   ymax <- max(obj$y)
#  if (deriv==0) curve(obj$fun(x, deriv=deriv),  xmin,xmax, ylim=c(ymin,ymax))
#   else curve(obj$fun(x, deriv=deriv),  xmin,xmax)
# }
#  pp<-fitPB(mcycle$times, mcycle$accel)